BootloaderMessage

Struct BootloaderMessage 

pub struct BootloaderMessage { /* private fields */ }
Processed bootloader message.

Implementations

Source

impl BootloaderMessage

pub fn with_args(args: &str) -> Self

Creates a new bootloader message with the given recovery arguments.

pub fn recovery_args(&self) -> impl Iterator<Item = &str>

Returns an iterator over all arguments specified in the bootloader message’s recovery field. Arguments are assumed to use a newline character (\n) as a delimiter.